@@ -32,17 +32,6 @@ sub file {
   }
 }
 
-sub file_optional {
-  my $self = shift;
-  if (@_) {
-    $self->{file_optional} = $_[0];
-    return $self;
-  }
-  else {
-    return $self->{file_optional};
-  }
-}
-
 sub ext {
   my $self = shift;
   if (@_) {
@@ -458,12 +447,8 @@ sub new {
   
   bless $self, ref $class || $class;
   
-  my $file_optional = $self->file_optional;
-  
-  my $file = $self->file;
-  if (!$file_optional && !defined $file) {
-    confess("The \"file\" field must be defined");
-  }
+  # [TODO]A config file name is set by load_config method. This is removed in a future release.
+  $self->file(undef);
   
   # cc
   unless (defined $self->{cc}) {
@@ -528,28 +513,6 @@ sub new {
     $self->spvm_core_include_dir($spvm_core_include_dir);
   }
   
-  # native_include_dir
-  unless (defined $self->native_include_dir) {
-    if (defined $file) {
-      my $native_dir = $self->_remove_ext_from_config_file($file);
-      $native_dir .= '.native';
-      my $native_include_dir = "$native_dir/include";
-      
-      $self->native_include_dir($native_include_dir);
-    }
-  }
-  
-  # native_src_dir
-  unless (defined $self->native_src_dir) {
-    if (defined $file) {
-      my $native_dir = $self->_remove_ext_from_config_file($file);
-      $native_dir .= '.native';
-      my $native_src_dir = "$native_dir/src";
-      
-      $self->native_src_dir($native_src_dir);
-    }
-  }
-  
   # source_files
   unless (defined $self->{source_files}) {
     $self->source_files([]);
@@ -874,6 +837,30 @@ sub load_config {
   
   push @{$config->get_loaded_config_files}, $config_file;
   
+  $config->file($config_file);
+  
+  # native_include_dir
+  unless (defined $config->native_include_dir) {
+    if (defined $config_file) {
+      my $native_dir = $config->_remove_ext_from_config_file($config_file);
+      $native_dir .= '.native';
+      my $native_include_dir = "$native_dir/include";
+      
+      $config->native_include_dir($native_include_dir);
+    }
+  }
+  
+  # native_src_dir
+  unless (defined $config->native_src_dir) {
+    if (defined $config_file) {
+      my $native_dir = $config->_remove_ext_from_config_file($config_file);
+      $native_dir .= '.native';
+      my $native_src_dir = "$native_dir/src";
+      
+      $config->native_src_dir($native_src_dir);
+    }
+  }
+  
   return $config;
 }
 
@@ -1449,16 +1436,7 @@ This field is automatically set and users nomally do not change it.
 
 Gets and sets C<file> field, the file path of this config.
 
-This field is set by L</"new"> method and users nomally do not change it.
-
-=head2 file_optional
-
-  my $file_optional = $config->file_optional;
-  $config->file_optional($file_optional);
-
-Gets and sets C<file_optional> field.
-
-If this field is a true value, even if the L<file|/"file"> field is not given to L</"new"> method, the exception is not thrown.
+This field is set by L</"load_config"> method and users should not set it.
 
 =head2 output_type
 
@@ -1568,12 +1546,14 @@ Gets and sets C<mode> field.
 
 Creates a new C<SPVM::Builder::Config> object with L<fields|/"Fields">, and returns it.
 
-The C<file> field must be defined.
-
 Field Default Values:
 
 =over 2
 
+=item * L</"file">
+
+This value is set automatically.
+
 =item * L</"cc">
 
 The C<$Config{cc}> of L<Config> module.
@@ -1714,14 +1694,6 @@ Other OSs:
 
 =back
 
-Exceptions:
-
-The "file" field must be defined. Otherwise, an exception is thrown.
-
-Exampels:
-
-  my $config = SPVM::Builder::Config->new(file => __FILE__);
-
 =head2 new_c
   
   my $config = SPVM::Builder::Config->new_c(file => __FILE__);
