@@ -290,8 +290,8 @@ enum {
   SPVM_OPCODE_C_ID_GET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR_UNDEF,
-  SPVM_OPCODE_C_ID_GOTO_END_OF_EVAL_ON_EXCEPTION,
-  SPVM_OPCODE_C_ID_GOTO_END_OF_METHOD_ON_EXCEPTION,
+  SPVM_OPCODE_C_ID_CATCH_ON_EXCEPTION,
+  SPVM_OPCODE_C_ID_RETURN_ON_EXCEPTION,
   SPVM_OPCODE_C_ID_ISA,
   SPVM_OPCODE_C_ID_ISA_ERROR,
   SPVM_OPCODE_C_ID_IS_TYPE,
